@@ -22,6 +22,9 @@ class ApiSettings(ApiBase):
     def aws_cloud_accounts(self):
         return self.build_route("settings/cloudaccounts/aws")
 
+    def gcp_stub_cloud_accounts(self):
+        return self.build_route("settings/cloudaccounts/gcp_stub")
+
     # todo old function -> tomer delete this in phase 2
     def add_compute_service_aks(self):
         return self.build_route("settings/cloudaccounts/azure/computeservices/aks")
@@ -61,6 +64,9 @@ class ApiSettings(ApiBase):
     def repository(self, name: str):
         return self.build_route(f"settings/repositories/{name}")
 
+    def repository_details(self, name: str):
+        return self.build_route(f"settings/repositories/{name}/details")
+
     def k8s_agent_deployment_yaml(self, cloud_account_name: str, compute_service_name: str, sandbox_namespaces: str):
         return self.build_route("settings/cloudaccounts/computeservices/k8s/agent-deployment-yaml"
                                 "?cloudAccount={cloud_account_name}"
