@@ -7,7 +7,6 @@ import time
 from isodate import duration_isoformat
 
 from gateways.apis.api_route_base import ApiRoot
-from gateways.bitbucket_gateway import BitbucketGateway
 from gateways.common.cs18_api_classes import BlueprintRepositoryDetails, AccessLink, \
     AddBlueprintUsingTokenRepositoryRequest, AddBlueprintGithubRepositoryRequest, \
     AddBlueprintBitbucketRepositoryRequest, BitbucketBlueprintRepositoryDetails
@@ -671,28 +670,44 @@ class Colony:
             deployment_type: str = None,
             wait_for_cache_refresh: bool = False,
     ):
-        if isinstance(repository_details, BitbucketBlueprintRepositoryDetails):
-            repository_details.code = self.get_auth_code_from_bitbucket(repository_details)
-            method_url = self._api_root.spaces.space_repositories(space_name=self.space, repository_type="bitbucket")
-            request = {
-                "repository_url": repository_details.repository_url,
-                "code": repository_details.code,
-                "repository_type": repository_details.repository_type,
-                "branch": repository_details.branch,
-                "type": deployment_type,
-                "redirection_url": repository_details.redirect_url
-            }
-        else:
-            print(
-                f'repository_url: {repository_details.repository_url} access_token: {repository_details.access_token}')
-            method_url = self._api_root.spaces.space_repositories(space_name=self.space)
-            request = {
-                "repository_url": repository_details.repository_url,
-                "access_token": repository_details.access_token,
-                "repository_type": repository_details.repository_type,
-                "branch": repository_details.branch,
-                "type": deployment_type
-            }
+        print(
+            f'repository_url: {repository_details.repository_url} access_token: {repository_details.access_token}')
+        method_url = self._api_root.spaces.space_repositories(space_name=self.space)
+        request = {
+            "repository_url": repository_details.repository_url,
+            "access_token": repository_details.access_token,
+            "repository_type": repository_details.repository_type,
+            "branch": repository_details.branch,
+            "type": deployment_type
+        }
+
+        resp = self.session.post(url=method_url, json=request)
+        GatewayUtils.handle_response(response=resp, return_codes=[200])
+
+        if wait_for_cache_refresh:
+            Utils.wait_for(
+                func=lambda: (not self.list_blueprints(exclude_samples=True) is False),
+                interval_sec=5,
+                max_retries=24,
+                subject="blueprints ready",
+            )
+
+    def add_bitbucket_repository_to_space_via_token(
+            self,
+            bitbucket_blueprint_repository_details: BitbucketBlueprintRepositoryDetails,
+            deployment_type: str = None,
+            wait_for_cache_refresh: bool = False,
+    ):
+
+        method_url = self._api_root.spaces.space_repositories(space_name=self.space, repository_type="bitbucket")
+        request = {
+            "repository_url": bitbucket_blueprint_repository_details.blueprint_repository_details.repository_url,
+            "code": bitbucket_blueprint_repository_details.auth_code,
+            "repository_type": bitbucket_blueprint_repository_details.blueprint_repository_details.repository_type,
+            "branch": bitbucket_blueprint_repository_details.blueprint_repository_details.branch,
+            "type": deployment_type,
+            "redirection_url": bitbucket_blueprint_repository_details.redirect_url
+        }
 
         resp = self.session.post(url=method_url, json=request)
         GatewayUtils.handle_response(response=resp, return_codes=[200])
@@ -1059,16 +1074,6 @@ class Colony:
         verify_json = json.loads(res.text)
         return Converters.create_verify_response(verify_json)
 
-    @staticmethod
-    def get_auth_code_from_bitbucket(repository_details):
-        with BitbucketGateway(
-                username=repository_details.username,
-                password=repository_details.password,
-                client_email=repository_details.client_email,
-                client_id=repository_details.client_id,
-                redirect_url=repository_details.redirect_url) as bitbucket:
-            return bitbucket.get_consumer_app_temporary_code()
-
     def add_sandbox_repository_to_space(
             self,
             space_name: str,
