@@ -46,7 +46,9 @@ from gateways.common.cs18_api_responses import (
     VerifyCloudProviderResponse, VerifyCloudProviderResourceResponse, AccountRepositoryResponse,
     BlueprintValidationResponse, BlueprintSourceResponse, CloudAccountCostResponse,
     ComputeServiceInAccountResponse, ComputeServiceInSpaceResponse, ComputeServiceSpaceSpecResponse,
-    K8SComputeServiceSpaceInfraSettingsResponse, BlueprintComputeServiceResponse)
+    K8SComputeServiceSpaceInfraSettingsResponse, BlueprintComputeServiceResponse,
+    AccountRepositoryDetailsBranchResponse, AccountRepositoryDetailsResponse,
+    SpaceRepositoryResponse, DirectAwsSshResponse, DirectAzureSshResponse, DirectRdpResponse)
 
 
 class Converters:
@@ -232,6 +234,7 @@ class Converters:
                 created_date=Converters._parse_datetime(compute_service.get("created_date", None)),
                 created_by=compute_service.get("created_by", None),
                 user_defined=compute_service.get("user_defined", None),
+                status=compute_service.get("status", None),
                 spaces=compute_service.get("spaces", [])
             )
             for compute_service in cloud_compute_services
@@ -249,6 +252,7 @@ class Converters:
                 created_date=Converters._parse_datetime(compute_service.get("created_date", None)),
                 created_by=compute_service.get("created_by", None),
                 user_defined=compute_service.get("user_defined", None),
+                status=compute_service.get("status", None),
                 spec=Converters._create_compute_service_space_spec_response(compute_service.get("spec"))
             )
             for compute_service in cloud_compute_services
@@ -387,7 +391,8 @@ class Converters:
             if sandbox.get("end_time", None) else None,
             debugging_service=sandbox.get('debugging_service'),
             launching_progress=Converters._create_launching_progress(sandbox.get('launching_progress')),
-            source=Converters._create_source(sandbox.get('source'))
+            source=Converters._create_source(sandbox.get('source')),
+            direct_access=sandbox.get('direct_access', 'off')
         )
 
     @staticmethod
@@ -433,7 +438,8 @@ class Converters:
             status_error_description=production["status_error_description"],
             has_green=production["has_green"],
             debugging_service=production.get('debugging_service'),
-            launching_progress=Converters._create_launching_progress(production.get('launching_progress'))
+            launching_progress=Converters._create_launching_progress(production.get('launching_progress')),
+            direct_access=production.get('direct_access', 'off')
         )
 
     @staticmethod
@@ -468,7 +474,9 @@ class Converters:
             status_error_description=production["status_error_description"],
             exposure=production["exposure"],
             debugging_service=production.get('debugging_service'),
-            launching_progress=Converters._create_launching_progress(production.get('launching_progress')))
+            launching_progress=Converters._create_launching_progress(production.get('launching_progress')),
+            direct_access=production.get('direct_access', 'off')
+        )
 
     @staticmethod
     def _create_sandbox_owner(user: dict) -> Optional[SandboxOwnerResponse]:
@@ -537,7 +545,8 @@ class Converters:
                 "scheduled_end_time") else None,
             end_time=dateutil.parser.parse(sandbox["end_time"]) if sandbox.get("end_time") else None,
             debugging_service=sandbox.get("debugging_service"),
-            source=Converters._create_source(sandbox.get('source'))
+            source=Converters._create_source(sandbox.get('source')),
+            direct_access=sandbox.get('direct_access', 'off')
         )
  
     @staticmethod
@@ -561,7 +570,8 @@ class Converters:
             deployment_start_time=Converters._parse_datetime(production.get("deployment_start_time")),
             blue_applications=[Converters._create_application_response_lean(x)
                                for x in production.get("blue_applications") or {}],
-            blue_services=[Converters._create_service_response(s) for s in production.get("services", [])]
+            blue_services=[Converters._create_service_response(s) for s in production.get("services", [])],
+            direct_access=production.get('direct_access', 'off')
         )
 
     @staticmethod
@@ -599,6 +609,7 @@ class Converters:
 
             if application.get("cloud")
             else None,
+            direct_access_protocols=application.get("direct_access_protocols", [])
         )
 
     @staticmethod
@@ -892,6 +903,18 @@ class Converters:
                                          repository_type=data['repository_type'],
                                          errors=[Error(e) for e in data["errors"]])
 
+    @staticmethod
+    def create_account_repository_details_branch_response(data: dict) -> AccountRepositoryDetailsBranchResponse:
+        return AccountRepositoryDetailsBranchResponse(name=data['name'])
+
+    @staticmethod
+    def create_account_repository_details_response(data: dict) -> AccountRepositoryDetailsResponse:
+        return AccountRepositoryDetailsResponse(repository_name=data['name'],
+                                                repository_full_name=data['full_name'],
+                                                default_branch=data['default_branch'],
+                                                branches=[AccountRepositoryDetailsBranchResponse(b)
+                                                          for b in data["branches"]])
+
     @staticmethod
     def _create_blueprint_compute_service(compute_service: dict) -> BlueprintComputeServiceResponse:
         return BlueprintComputeServiceResponse(
@@ -901,3 +924,29 @@ class Converters:
             created_by=compute_service.get("created_by", None),
             user_defined=compute_service.get("user_defined", None)
         )
+
+    @staticmethod
+    def create_space_repository_response(data: dict) -> SpaceRepositoryResponse:
+        return SpaceRepositoryResponse(repository_name=data['name'],
+                                       repository_type=data['repository_type'],
+                                       repository_url=data['repository_url'],
+                                       branch=data['branch'])
+
+    @staticmethod
+    def create_direct_aws_ssh_response(data: dict) -> DirectAwsSshResponse:
+        return DirectAwsSshResponse(
+            connection=data["connection"],
+            pem_file_url=data["pem_file_url"])
+
+    @staticmethod
+    def create_direct_azure_ssh_response(data: dict) -> DirectAzureSshResponse:
+        return DirectAzureSshResponse(
+            connection=data["connection"],
+            password=data["password"])
+
+    @staticmethod
+    def create_direct_rdp_response(data: dict) -> DirectRdpResponse:
+        return DirectRdpResponse(
+            rdp_file_url=data["rdp_file_url"],
+            username=data["username"],
+            password=data["password"])
